#19/01/2024

0.0.2

#Se actualiza la libreria, faltaba un self en la linea 226#
#cant_registros_db = Api.check_base_sqlserver(**self**, data['data_db']['server_name']#

0.0.3
se actualiza init, estaba mal configurado / from .Api import Api